#!/bin/sh

# This small script lets you choose your window manager via kdialog

# Detect if compiz is already running. If so, set selection to compiz as default
/sbin/pidof /usr/bin/kwin > /dev/null && USED_WM="KWin"
/sbin/pidof /usr/bin/compiz > /dev/null && USED_WM="Compiz"

# select the window manager
WM=`kdialog --icon kde-desktop-effects --caption "Compiz Switcher" --default "$USED_WM" --menu "KDE window manager:" kwin "KWin" compiz-manager "Compiz"` || exit 1

# just a small debug output to command line
echo "Using $WM as window manager"

# Replace the running window manager by the selected one
$WM --replace & 

# Don't save changes if compiz-manager could not start
if [ $WM = compiz-manager ];then
  # wait a few seconds to give compiz some time to start
  sleep 5s 
  /sbin/pidof /usr/bin/compiz > /dev/null
  RETVAL=$? 
  if [ $RETVAL = 1 ];then
    echo "Compiz could not be enabled."
    kdialog --passivepopup "Compiz could not be enabled." 5 &
    exit 1
  elif [ $RETVAL = 0 ];then
    echo "Compiz is enabled." 
    kdialog --passivepopup "Compiz is enabled." 5 &
  fi
elif [ $WM = kwin ];then
  echo "Compiz is disabled."
  kdialog --passivepopup "Compiz is disabled." 5 &
fi

# save changes
echo "Saving chosen window manager to use it on the next startup of KDE"
echo "Remove ~/.kde/env/kdewm.sh if you encounter problems."
mkdir -p ~/.kde/env
cat > ~/.kde/env/kdewm.sh << EOF
# This file is automatically generated. All changes to this file will be lost!
KDEWM=$WM
export KDEWM
EOF

